.. -*- coding: utf-8 -*-

.. _`ifabp-water-dataset`:

I-FABP in water dataset
=======================

The trajectory is a short MD run of I-FABP (intestinal fatty acid
binding protein) in water.

It was simulated in CHARMM for 500 ps with a 2 fs timestep. Frames
were saved every 1 ps and the trajectory was RMSD-fitted to the
protein.

There are 500 frames in the trajectory.

It is used as a test case for the `hop
<https://github.com/Becksteinlab/hop>`_ package.


Notes
-----

Data set characteristics:

 :size: 74 MB
 :number of trajectories: 1
 :number of frames:  500
 :number of particles: 12445
 :creator: Oliver Beckstein
 :URL:  `10.6084/m9.figshare.7058030.v1 <https://doi.org/10.6084/m9.figshare.7058030.v1>`_
 :license: `CC-BY 4.0 <https://creativecommons.org/licenses/by/4.0/legalcode>`_
 :reference: [Beckstein2018]_
    

.. [Beckstein2018] Beckstein, Oliver (2018): Molecular dynamics
   trajectory of I-FABP for testing and benchmarking solvent dynamics
   analysis. figshare. Fileset. DOI: `10.6084/m9.figshare.7058030.v1
   <https://doi.org/10.6084/m9.figshare.7058030.v1>`_

